@@ -23,15 +23,15 @@
 #include <glib.h>
 #include <time.h>
 
-gboolean set_system_timezone     (const char  *filename, 
-                                  GError     **err);
 gint     can_set_system_timezone (void);
 
 gint     can_set_system_time     (void);
 
-void     set_system_time_async   (gint64         time,
-                                  GFunc          callback,
-                                  gpointer       data,
-                                  GDestroyNotify notify);
+void     set_system_timezone_async   (const gchar          *tz,
+                                      GAsyncReadyCallback   callback,
+                                      gpointer              user_data);
+
+gboolean set_system_timezone_finish  (GAsyncResult         *result,
+                                      GError              **error);
 
 #endif
